@@ -1,18 +1,17 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-from sqlalchemy import func
+from tornado.gen import coroutine
 
-from holmes.models import Domain, Page
+from holmes.models import Domain
 from holmes.handlers import BaseHandler
 
 
 class DomainsHandler(BaseHandler):
 
+    @coroutine
     def get(self):
         domains = self.db.query(Domain).order_by(Domain.name.asc()).all()
-        violations_per_domain = Domain.get_violations_per_domain(self.db)
-        pages_per_domain = Domain.get_pages_per_domain(self.db)
 
         if not domains:
             self.write("[]")
@@ -21,11 +20,22 @@ class DomainsHandler(BaseHandler):
         result = []
 
         for domain in domains:
+            page_count = yield self.cache.get_page_count(domain)
+            review_count = yield self.cache.get_active_review_count(domain)
+            violation_count = yield self.cache.get_violation_count(domain)
+
+            if page_count > 0:
+                review_percentage = round(float(review_count) / page_count * 100, 2)
+            else:
+                review_percentage = 0
+
             result.append({
                 "url": domain.url,
                 "name": domain.name,
-                "violationCount": violations_per_domain.get(domain.id, 0),
-                "pageCount": pages_per_domain.get(domain.id, 0)
+                "violationCount": violation_count,
+                "pageCount": page_count,
+                "reviewCount": review_count,
+                "reviewPercentage": review_percentage
             })
 
         self.write_json(result)
@@ -33,6 +43,7 @@ class DomainsHandler(BaseHandler):
 
 class DomainDetailsHandler(BaseHandler):
 
+    @coroutine
     def get(self, domain_name):
         domain = Domain.get_domain_by_name(domain_name, self.db)
 
@@ -40,14 +51,22 @@ class DomainDetailsHandler(BaseHandler):
             self.set_status(404, 'Domain %s not found' % domain_name)
             return
 
-        page_count = domain.get_page_count(self.db)
-        violation_count = domain.get_violation_data(self.db)
+        page_count = yield self.cache.get_page_count(domain)
+        review_count = yield self.cache.get_active_review_count(domain)
+        violation_count = yield self.cache.get_violation_count(domain)
+
+        if page_count > 0:
+            review_percentage = round(float(review_count) / page_count * 100, 2)
+        else:
+            review_percentage = 0
 
         domain_json = {
             "name": domain.name,
             "url": domain.url,
             "pageCount": page_count,
+            "reviewCount": review_count,
             "violationCount": violation_count,
+            "reviewPercentage": review_percentage
         }
 
         self.write_json(domain_json)
@@ -85,39 +104,25 @@ class DomainReviewsHandler(BaseHandler):
             self.set_status(404, 'Domain %s not found' % domain_name)
             return
 
-        review_count = domain.get_active_review_count(self.db)
-        reviews = domain.get_active_reviews(self.db, current_page=current_page, page_size=page_size)
+        reviews = domain.get_active_reviews(
+            self.db,
+            current_page=current_page,
+            page_size=page_size
+        )
 
         result = {
             'domainName': domain.name,
             'domainURL': domain.url,
-            'pageCount': review_count,
             'pages': [],
-            'pagesWithoutReview': []
         }
 
-        for review in reviews:
+        for page in reviews:
             result['pages'].append({
-                "url": review.page.url,
-                "uuid": str(review.page.uuid),
-                "violationCount": len(review.violations),
-                "completedAt": review.completed_date,
-                "reviewId": str(review.uuid)
+                "url": page.url,
+                "uuid": str(page.uuid),
+                "violationCount": page.violations_count,
+                "completedAt": page.last_review_date,
+                "reviewId": str(page.last_review_uuid)
             })
 
-        pages = self.db.query(Page).filter(Page.domain == domain, Page.last_review_date == None)[:10]
-        for page in pages:
-            result['pagesWithoutReview'].append({
-                'uuid': str(page.uuid),
-                'url': page.url
-            })
-
-        page_count = self.db.query(func.count(Page.id)).filter(Page.domain_id == domain.id, Page.last_review_date == None).scalar()
-
-        page_count = page_count - len(pages)
-        if page_count <= 0:
-            page_count = 0
-
-        result['pagesWithoutReviewCount'] = page_count
-
         self.write_json(result)
